define("app", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        configExceptionHandler.$inject = ["$provide"];
        configIonicProvider.$inject = ["$ionicConfigProvider"];
        configLoadingBar.$inject = ["cfpLoadingBarProvider"];
        configRouterProvider.$inject = ["$urlRouterProvider"];
        configStateProvider.$inject = ["$stateProvider"];
        configHttpProvider.$inject = ["$httpProvider"];
        AppController.$inject = ["$scope", "$rootScope", "$state", "$ionicHelper", "$ionicPlatform", "$supersonic", "VkApi", "$tapjoy", "$fyber", "$trialpay", "$cordovaDialogs", "UserService", "VotesService", "profile", "Config"];
        directiveBrowseTo.$inject = ["$ionicGesture"];
        run.$inject = ["$rootScope", "$state", "$http", "$ionicPlatform", "$ionicSideMenuDelegate", "$cordovaDialogs", "$tapjoy", "Config", "VkApi"];
        function configExceptionHandler($provide) {
            $provide.decorator("$exceptionHandler", ["$delegate", "$injector", function ($delegate, $injector) {
                return function (exception, cause) {
                    var message = exception && exception.message || "Неизвестная ошибка",
                        ignoreErrors = ["collection-repeat", "angular", "ng:"],
                        ignoreErrorsRegex = new RegExp("/(" + ignoreErrors.join("|") + ")/gi"),
                        showError = ignoreErrorsRegex.test(message);

                    $delegate(exception, cause);

                    // ignore some errors in notification
                    if (showError && $injector.has("$cordovaToast")) {
                        $injector.get("$cordovaToast").show(message, "long", "bottom");
                    }
                };
            }]);
        }

        /**
         * @ngInject
         */
        function configIonicProvider($ionicConfigProvider) {
            $ionicConfigProvider.views.maxCache(0);
        }

        /**
         * @ngInject
         */
        function configLoadingBar(cfpLoadingBarProvider) {
            cfpLoadingBarProvider.includeSpinner = false;
            cfpLoadingBarProvider.latencyThreshold = 500;
        }

        /**
         * @ngInject
         */
        function configRouterProvider($urlRouterProvider) {
            $urlRouterProvider.otherwise("/feed/tasks");
        }

        /**
         * @ngInject
         */
        function configStateProvider($stateProvider) {
            $stateProvider.state("root", {
                controller: "AppController",
                templateUrl: "templates/layout.tpl.html",
                resolve: {
                    profile: ["$state", "$http", "VkApi", "UserService", function profile($state, $http, VkApi, UserService) {
                        $http.defaults.headers.common["X-User-Id"] = VkApi.getUserId();
                        $http.defaults.headers.common["X-Access-Token"] = VkApi.getAccessToken();

                        return UserService.getProfile()["catch"](function () {
                            VkApi.logout();
                            $state.go("auth.login");
                        });
                    }]
                }
            });
        }

        /**
         * @ngInject
         */
        function configHttpProvider($httpProvider) {
            var interceptor = ["$injector", "$q", "$rootScope", "$cordovaDialogs", function ($injector, $q, $rootScope, $cordovaDialogs) {

                function handleError(response) {
                    if (!response.config.nointercept) {
                        var errorCode,
                            errorMessage,
                            data = response.data || {};

                        if (data.error) {
                            errorCode = data.error.code || data.error.error_code || response.status;
                            errorMessage = data.error.message || data.error.error_msg || response.statusText;
                        } else {
                            errorCode = response.status;
                            errorMessage = data.message || response.statusText;
                        }

                        $rootScope.error = errorMessage;

                        if (response.status === 401) {
                            $injector.get("VkApi").logout();
                            $injector.get("$state").transitionTo("auth.login");
                        }

                        if (typeof errorMessage === "string") {
                            $cordovaDialogs.alert(errorMessage, "Ошибка", "OK");
                        } else {
                            $cordovaDialogs.alert("Неизвестная ошибка", "Ошибка", "OK");
                        }
                    }
                }

                return {
                    response: (function (_response) {
                        var _responseWrapper = function response(_x) {
                            return _response.apply(this, arguments);
                        };

                        _responseWrapper.toString = function () {
                            return _response.toString();
                        };

                        return _responseWrapper;
                    })(function (response) {
                        if (response.data.error) {
                            handleError(response);

                            return $q.reject(response);
                        }

                        return response;
                    }),
                    responseError: function responseError(response) {
                        handleError(response);

                        return $q.reject(response);
                    }
                };
            }];

            $httpProvider.interceptors.push(interceptor);
        }

        /**
         * @ngInject
         */
        function AppController($scope, $rootScope, $state, $ionicHelper, $ionicPlatform, $supersonic, VkApi, $tapjoy, $fyber, $trialpay, $cordovaDialogs, UserService, VotesService, profile, Config) {

            $supersonic.init(Config.SUPERSONIC_APP_KEY, profile.id).then(function () {})["catch"](function (error) {});

            $fyber.initialize(Config.FYBER_APP_ID, profile.id, Config.FYBER_CLIENT_SECURITY_TOKEN).then(function () {})["catch"](function (error) {});

            $trialpay.initialize(Config.TRIALPAY_APP_KEY, profile.id).then(function () {})["catch"](function (error) {});

            function logout() {
                VkApi.logout();
                $state.go("auth.login");
            }

            $scope.logout = logout;

            $rootScope.profile = profile;
            $rootScope.profile.displayName = profile.first_name + " " + profile.last_name;

            if (profile.id) {
                $tapjoy.setUserID(profile.id);
            }

            UserService.getBonus().then(function (count) {
                $cordovaDialogs.alert("Вам начислен ежедневный бонус " + count + " монет. Заходи каждый день и получай монеты!", " ", "OK");
            });

            $scope.showHelper = function () {
                $state.go("tasks-feed");
                $ionicHelper.show({
                    scope: $scope,
                    templateUrl: "templates/help.tpl.html"
                });
            };

            $scope.hideHelper = function () {
                $ionicHelper.hide();
            };

            $ionicPlatform.registerBackButtonAction(function () {
                if (!$ionicHelper.showed) {
                    if ($state.current.name === "tasks-feed") {
                        navigator.app.exitApp();
                    } else {
                        $state.go("tasks-feed");
                    }
                } else {
                    $ionicHelper.hide();
                }
            }, 100);

            $scope.goBack = function () {

                if ($state.includes("tasks-view")) {
                    $state.go("tasks-feed");
                }
            };

            $scope.showBackButton = function () {
                return $state.includes("tasks-view");
            };

            $scope.initCoinsPerVote = function () {
                VotesService.rate().then(function (response) {
                    $scope.coinsPerVote = response.data.rate;
                });
            };

            $scope.initCoinsPerVote();
        }

        /**
         * @ngInject
         */
        function directiveBrowseTo($ionicGesture) {
            return {
                restrict: "A",
                link: function link($scope, $element, $attrs) {

                    var handleTap = function handleTap() {
                        //noinspection JSCheckFunctionSignatures
                        window.open(encodeURI($attrs.browseTo), "_system");
                    };

                    var tapGesture = $ionicGesture.on("tap", handleTap, $element);

                    $scope.$on("$destroy", function () {
                        // Clean up - unbind drag gesture handler
                        $ionicGesture.off(tapGesture, "tap", handleTap);
                    });
                }
            };
        }

        /**
        * @ngInject
        */
        function run($rootScope, $state, $http, $ionicPlatform, $ionicSideMenuDelegate, $cordovaDialogs, $tapjoy, Config, VkApi) {

            function onHardwareMenuKeyDown() {
                $ionicSideMenuDelegate.toggleLeft();
            }

            function onIonicPlatformReady() {
                /** @namespace cordova.platformId */
                /** @namespace cordova.getAppVersion */
                /** @namespace cordova.plugins.Keyboard */
                /** @namespace window.device */
                /** @namespace navigator.splashscreen */

                // Hide or show accessory bar above the keyboard for form inputs by default
                if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
                    window.cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
                }

                // cordova-plugin-statusbar required
                if (window.StatusBar) {
                    window.StatusBar.overlaysWebView(true);
                    window.StatusBar.styleLightContent();

                    if (cordova.platformId === "android") {
                        window.StatusBar.backgroundColorByHexString("#00A0BF");
                    }
                }

                // https://github.com/whiteoctober/cordova-plugin-app-version required
                if (window.cordova && typeof window.cordova.getAppVersion === "function") {
                    window.cordova.getAppVersion(function (version) {
                        if (version !== "undefined") {
                            $http.defaults.headers.common["X-App-Version"] = version;
                        }
                    });
                }

                // cordova-plugin-device required
                if (typeof window.device !== "undefined") {
                    var uuid = window.device.uuid;

                    if (uuid !== "undefined") {
                        $http.defaults.headers.common["X-Device-Id"] = uuid.replace(/\W/g, "").toLowerCase();
                    }
                }

                setTimeout(function () {
                    if (navigator.splashscreen) {
                        navigator.splashscreen.hide();
                    }
                }, 3000);

                $tapjoy.connect(Config.TAPJOY_SECRET_KEY).then(function () {
                    return $tapjoy.setSenderID(Config.TAPJOY_SENDER_ID);
                }).then(function () {
                    //noinspection UnreachableCodeJS
                    return $tapjoy.setDebugEnabled(false);
                })["catch"](function (error) {});

                document.addEventListener("menubutton", onHardwareMenuKeyDown, false);
            }

            $ionicPlatform.ready(onIonicPlatformReady);

            var statesThatDontRequireAuth = ["auth.login", "auth.logout"];

            $rootScope.$on("$stateChangeStart", function (event, toState) {
                if (statesThatDontRequireAuth.indexOf(toState.name) === -1 && !VkApi.isAuthenticated()) {
                    $state.transitionTo("auth.login");
                    event.preventDefault();
                } else if (statesThatDontRequireAuth.indexOf(toState.name) !== -1 && VkApi.isAuthenticated()) {
                    $state.transitionTo("tasks-feed");
                    event.preventDefault();
                }
            });

            $rootScope.$on("$stateChangeSuccess", function (event, toState) {
                $rootScope.activeTabs = toState.data && toState.data.showTabs;
            });

            $rootScope.$on("VkApiException:AuthFailed", function () {
                $cordovaDialogs.alert("Ошибка авторизации. Пожалуйста, попробуйте повторить попытку еще раз.", "Ошибка", "OK");

                $state.transitionTo("auth.login");
            });

            $rootScope.$on("VkApiException:WrongApp", function () {
                $state.transitionTo("auth.login");

                $cordovaDialogs.alert("Возникла ошибка при авторизации приложения на сервере Вконтакте. Пожалуйста, попробуйте повторить попытку еще раз.", "Ошибка", "OK");
            });
        }

        angular.module("tap2app-app", [
        // modules
        "tap2app-app.config", "tap2app-app.auth", "tap2app-app.home", "tap2app-app.user", "tap2app-app.task", "tap2app-app.advert",
        // components
        "cordovaDialogs", "cordovaClipboard", "cordovaEmailComposer", "vkApi", "vkServices", "ngTabs",
        //'parse',
        "fabric", "tapJoy", "superSonic", "fyber", "trialpay", "formValidate", "ionicHelper",
        // vendor
        "ionic", "angular-loading-bar"]).config(configExceptionHandler).config(configIonicProvider).config(configLoadingBar).config(configRouterProvider).config(configStateProvider).config(configHttpProvider).directive("browseTo", directiveBrowseTo).controller("AppController", AppController).run(run);
    })();
});
define("config", ["exports"], function (exports) {
    /* disable warnings about duplicate hash keys for this file */
    /*jshint -W075 */

    //noinspection JSDuplicatedDeclaration,JSLastCommaInObjectLiteral,SpellCheckingInspection
    "use strict";

    angular.module("tap2app-app.config", []).constant("Config", {
        API_BASEURL: "http://app.tap2app.ru/api",
        TAPJOY_APP_ID: "139bf3d6-b1ae-469f-8c08-2738689b6827",
        TAPJOY_SECRET_KEY: "E5vz1rGuRp-MCCc4aJtoJwECrMCyh5a6cCpfjbgHD8kiNd89GQ7LeA2DBdSu",
        TAPJOY_SENDER_ID: "581131271399",
        SUPERSONIC_APP_KEY: "569c0125",
        FYBER_APP_ID: "60607",
        FYBER_CLIENT_SECURITY_TOKEN: "4b349311976be85790a43c5e23ce1b71",
        TRIALPAY_APP_KEY: "4c00ca5c38cff6832c0a9da26583c015" });

    /* jshint +W075 */
});
define("components/clipboard/clipboard", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        CordovaClipboard.$inject = ["$q", "$window"];
        function CordovaClipboard($q, $window) {
            return {
                copy: function copy(text) {
                    var q = $q.defer();

                    $window.cordova.plugins.clipboard.copy(text, function () {
                        q.resolve();
                    }, function () {
                        q.reject();
                    });

                    return q.promise;
                },

                paste: function paste() {
                    var q = $q.defer();

                    $window.cordova.plugins.clipboard.paste(function (text) {
                        q.resolve(text);
                    }, function () {
                        q.reject();
                    });

                    return q.promise;
                }
            };
        }

        angular.module("cordovaClipboard", []).factory("$cordovaClipboard", CordovaClipboard);
    })();
});
define("components/cordova-dialogs/cordova-dialogs", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        CordovaDialog.$inject = ["$q", "$window"];
        function CordovaDialog($q, $window) {
            return {
                alert: function alert(message, title, buttonName) {
                    var deferred = $q.defer();

                    if (typeof message === "object") {
                        message = JSON.stringify(message);
                    }

                    if (typeof title !== "string") {
                        title = "Alert";
                    }

                    if (!$window.navigator.notification) {
                        $window.alert(message);
                        deferred.resolve();
                    } else {
                        navigator.notification.alert(message, function () {
                            deferred.resolve();
                        }, title, buttonName);
                    }

                    return deferred.promise;
                },

                confirm: function confirm(message, title, buttonLabels) {
                    var deferred = $q.defer();

                    if (!$window.navigator.notification) {
                        if ($window.confirm(message)) {
                            deferred.resolve(1);
                        } else {
                            deferred.resolve(2);
                        }
                    } else {
                        navigator.notification.confirm(message, function (buttonIndex) {
                            deferred.resolve(buttonIndex);
                        }, title, buttonLabels);
                    }

                    return deferred.promise;
                },

                prompt: function prompt(message, title, buttonLabels, defaultText) {
                    var deferred = $q.defer();

                    if (!$window.navigator.notification) {
                        var res = $window.prompt(message, defaultText);

                        if (res !== null) {
                            deferred.resolve({ input1: res, buttonIndex: 1 });
                        } else {
                            deferred.resolve({ input1: res, buttonIndex: 2 });
                        }
                    } else {
                        navigator.notification.prompt(message, function (result) {
                            deferred.resolve(result);
                        }, title, buttonLabels, defaultText);
                    }

                    return deferred.promise;
                },

                beep: function beep(times) {
                    return navigator.notification.beep(times);
                }
            };
        }

        angular.module("cordovaDialogs", []).factory("$cordovaDialogs", CordovaDialog);
    })();
});
define("components/email-composer/email-composer", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        CordovaEmailComposer.$inject = ["$q", "$window"];
        function CordovaEmailComposer($q, $window) {
            return {
                isAvailable: function isAvailable() {
                    var q = $q.defer();

                    $window.cordova.plugins.email.isAvailable(function (isAvailable) {
                        if (isAvailable) {
                            q.resolve();
                        } else {
                            q.reject();
                        }
                    });

                    return q.promise;
                },

                open: function open(properties) {
                    var q = $q.defer();

                    $window.cordova.plugins.email.open(properties, function () {
                        q.reject(); // user closed email composer
                    });

                    return q.promise;
                },

                addAlias: function addAlias(app, schema) {
                    cordova.plugins.email.addAlias(app, schema);
                }
            };
        }

        angular.module("cordovaEmailComposer", []).factory("$cordovaEmailComposer", CordovaEmailComposer);
    })();
});
define("components/fabric/fabric", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        FabricAnswers.$inject = ["$window"];
        FabricCrashlytics.$inject = ["$window"];
        runFabric.$inject = ["$rootScope", "$state", "$fabricAnswers"];
        function FabricAnswers($window) {
            return {
                sendLogIn: function sendLogIn() {
                    $window.fabric.Answers.sendLogIn();
                },
                sendSignUp: function sendSignUp() {
                    $window.fabric.Answers.sendSignUp();
                },
                sendContentView: function sendContentView(name, type, id, attributes) {
                    $window.fabric.Answers.sendContentView(name, type, id, attributes);
                },
                sendScreenView: function sendScreenView(name, id, attributes) {
                    $window.fabric.Answers.sendScreenView(name, id, attributes);
                },
                sendCustomEvent: function sendCustomEvent(ame, attributes) {
                    $window.fabric.Answers.sendCustomEvent(name, attributes);
                }
            };
        }

        /**
         * @ngInject
         */
        function FabricCrashlytics($window) {
            return {
                setUserIdentifier: function setUserIdentifier(value) {
                    $window.fabric.Crashlytics.setUserIdentifier(value);
                },
                setUserName: function setUserName(value) {
                    $window.fabric.Crashlytics.setUserName(value);
                },
                setUserEmail: function setUserEmail(value) {
                    $window.fabric.Crashlytics.setUserEmail(value);
                },
                setStringValueForKey: function setStringValueForKey(value, key) {
                    $window.fabric.Crashlytics.setStringValueForKey(value, key);
                },
                setIntValueForKey: function setIntValueForKey(value, key) {
                    $window.fabric.Crashlytics.setIntValueForKey(value, key);
                },
                setBoolValueForKey: function setBoolValueForKey(value, key) {
                    $window.fabric.Crashlytics.setBoolValueForKey(value, key);
                },
                setFloatValueForKey: function setFloatValueForKey(value, key) {
                    $window.fabric.Crashlytics.setFloatValueForKey(value, key);
                },
                addLog: function addLog(value) {
                    $window.fabric.Crashlytics.addLog(value);
                },
                sendCrash: function sendCrash() {
                    $window.fabric.Crashlytics.sendCrash();
                }
            };
        }

        /**
         * @ngInject
         */
        function runFabric($rootScope, $state, $fabricAnswers) {
            $rootScope.$on("auth.logged.in", function (event, auth) {
                $fabricAnswers.sendSignUp();
            });

            $rootScope.$on("$ionicView.enter", function () {
                var stateName = $state.current && $state.current.name;

                $fabricAnswers.sendScreenView(stateName, stateName);
            });
        }

        angular.module("fabric", []).factory("$fabricAnswers", FabricAnswers).factory("$fabricCrashlytics", FabricCrashlytics).run(runFabric);
    })();
});
define("components/form-validate/form", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        onValidSubmit.$inject = ["$parse"];
        function onValidSubmit($parse) {
            return {
                require: "^form",
                restrict: "A",
                link: function link(scope, element, attrs, form) {
                    form.$submitted = false;
                    var fn = $parse(attrs.onValidSubmit);
                    element.on("submit", function (event) {
                        scope.$apply(function () {
                            element.addClass("ng-submitted");
                            form.$submitted = true;

                            if (form.$valid) {
                                if (typeof fn === "function") {
                                    fn(scope, { $event: event });
                                }
                            }
                        });
                    });
                }
            };
        }

        function validated() {
            return {
                restrict: "AEC",
                require: "^form",
                link: function link(scope, element, attrs, form) {
                    var inputs = element.find("*");

                    var processInputs = function processInputs(input) {
                        var attributes = input.attributes;
                        if (attributes.getNamedItem("ng-model") != void 0 && attributes.getNamedItem("name") != void 0) {
                            var field = form[attributes.name.value];
                            if (field != void 0) {
                                scope.$watch(function () {
                                    return form.$submitted + "_" + field.$valid;
                                }, function () {
                                    if (form.$submitted != true) {
                                        return;
                                    }

                                    var inp = angular.element(input);
                                    if (inp.hasClass("ng-invalid")) {
                                        element.removeClass("has-success");
                                        element.addClass("has-error");
                                    } else {
                                        element.removeClass("has-error").addClass("has-success");
                                    }
                                });
                            }
                        }
                    };

                    for (var i = 0; i < inputs.length; i++) {
                        processInputs(inputs[i]);
                    }
                }
            };
        }

        angular.module("formValidate", []).directive("onValidSubmit", onValidSubmit).directive("validated", validated);
    })();
});
define("components/ionic-helper/ionic-helper", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        $ionicHelper.$inject = ["$rootScope", "$ionicBackdrop", "$ionicTemplateLoader", "$document"];
        function $ionicHelper($rootScope, $ionicBackdrop, $ionicTemplateLoader, $document) {
            var templatePromise,
                showed = false;

            function showHelper(options) {
                var scope = options.scope && options.scope.$new() || $rootScope.$new(true),
                    templateUrl = options.templateUrl;

                $ionicBackdrop.retain();

                templatePromise = $ionicTemplateLoader.compile({
                    templateUrl: templateUrl,
                    scope: scope,
                    appendTo: $document[0].body
                });

                this.showed = true;
            }

            function hideHelper() {
                $ionicBackdrop.release();

                if (templatePromise) {
                    templatePromise.then(function (loader) {
                        loader.element[0].classList.add("hide");
                    });
                }

                this.showed = false;
            }

            return {
                show: showHelper,
                hide: hideHelper,
                showed: showed
            };
        }

        angular.module("ionicHelper", ["ionic"]).factory("$ionicHelper", $ionicHelper);
    })();
});
define("components/fyber/fyber", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        fyber.$inject = ["$q"];
        function fyber($q) {
            var _fyber = {};

            _fyber.initialize = function (appKey, userId, securityToken, virtualCurrencyName) {
                var deferred = $q.defer();

                window.plugins.fyber.initialize({
                    appKey: appKey,
                    userId: userId,
                    securityToken: securityToken,
                    virtualCurrencyName: virtualCurrencyName
                }, null, null, null, function () {
                    deferred.resolve("Fyber Success Initialize!");
                }, function () {
                    deferred.reject("Fyber Error Initialize!");
                });

                return deferred.promise;
            };

            _fyber.showOfferwall = function () {
                var deferred = $q.defer();

                window.plugins.fyber.showOfferwall(function () {
                    deferred.resolve("Fyber Success Show OfferWall!");
                }, function () {
                    deferred.reject("Fyber Error Show OfferWall!");
                });

                return deferred.promise;
            };

            _fyber.onCloseOfferWall = function (callback) {
                window.plugins.fyber.onCloseOfferWall(callback);
            };

            return _fyber;
        }

        angular.module("fyber", []).factory("$fyber", fyber);
    })();
});
define("components/spinbox/spinbox", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        function spinBox() {
            return {
                restrict: "E",
                templateUrl: "templates/components/spinbox/view.tpl.html",
                scope: {
                    name: "@",
                    model: "=ngModel",
                    min: "@"
                },
                compile: function compile(element, attrs) {
                    attrs.min = attrs.min || 1;
                },
                controller: ["$scope", function controller($scope) {
                    if (!$scope.model) {
                        $scope.model = parseInt(10);
                    }

                    $scope.increase = function () {
                        $scope.model++;
                    };

                    $scope.reduce = function () {
                        if ($scope.model > $scope.min) {
                            $scope.model--;
                        }
                    };
                }]
            };
        }

        angular.module("ngSpinbox", []).directive("spinBox", spinBox);
    })();
});
define("components/supersonic/supersonic", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        superSonic.$inject = ["$q"];
        function superSonic($q) {
            var _supersonic = {};

            _supersonic.init = function (appKey, userId) {
                var deferred = $q.defer();

                window.plugins.supersonic.initialize({ appKey: appKey, userId: userId }, null, function () {
                    deferred.resolve("Supersonic Success Initialized!");
                }, function () {
                    deferred.reject("Supersonic Error Initialized!");
                });

                return deferred.promise;
            };

            _supersonic.showOfferwall = function () {
                var deferred = $q.defer();

                window.plugins.supersonic.showOfferwall(function () {
                    deferred.resolve("Supersonic Success Show Offerwall!");
                }, function () {
                    deferred.reject("Supersonic Error Show Offerwall!");
                });

                return deferred.promise;
            };

            _supersonic.closeOfferwall = function (callback) {
                window.plugins.supersonic.closeOfferwall(callback);
            };

            return _supersonic;
        }

        angular.module("superSonic", []).factory("$supersonic", superSonic);
    })();
});
define("components/tabs/tabs", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        ngTabbar.$inject = ["$window", "$location", "$tabbar"];
        function tabbarProvider() {
            var defaults = this.defaults = {
                activeClass: "tab-item-active",
                routeAttr: "data-match-route",
                strict: false
            };

            this.$get = function () {
                return { defaults: defaults };
            };
        }

        /**
         * @ngInject
         */
        function ngTabbar($window, $location, $tabbar) {

            var defaults = $tabbar.defaults;

            return {
                restrict: "A",
                link: function postLink(scope, element, attr, controller) {

                    // Directive options
                    var options = angular.copy(defaults);
                    angular.forEach(Object.keys(defaults), function (key) {
                        if (angular.isDefined(attr[key])) {
                            options[key] = attr[key];
                        }
                    });

                    // Watch for the $location
                    scope.$watch(function () {
                        return $location.path();
                    }, function (newValue, oldValue) {

                        var aElements = element[0].querySelectorAll("a[" + options.routeAttr + "]");

                        angular.forEach(aElements, function (li) {
                            var liElement = angular.element(li),
                                pattern = liElement.attr(options.routeAttr).replace("/", "\\/");

                            if (options.strict) {
                                pattern = "^" + pattern + "$";
                            }

                            var regexp = new RegExp(pattern, ["i"]);
                            if (regexp.test(newValue)) {
                                liElement.addClass(options.activeClass);
                            } else {
                                liElement.removeClass(options.activeClass);
                            }
                        });
                    });
                }
            };
        }

        /**
         * @ngInject
         */
        function ngTabs() {
            return {
                restrict: "E",
                transclude: true,
                template: "<div class=\"tabs tabs-icon-top\" ng-transclude></div>"
            };
        }

        /**
         * @ngInject
         */
        function ngTab() {
            return {
                restrict: "EA",
                require: "ngTab",
                replace: true,
                transclude: true,
                scope: {
                    title: "@",
                    icon: "@"
                },
                template: "<a class=\"tab-item\"><i class=\"icon\" ng-class=\"icon\"></i><span class=\"tab-title\" ng-bind=\"title\"></span></a>"
            };
        }

        angular.module("ngTabs", ["ui.router"]).provider("$tabbar", tabbarProvider).directive("ngTabbar", ngTabbar).directive("ngTabs", ngTabs).directive("ngTab", ngTab);
    })();
});
define("components/tapjoy/tapjoy", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        tapJoy.$inject = ["$q"];
        function tapJoy($q) {
            var _tapjoy = {};

            _tapjoy.connect = function (secretKey) {
                var deferred = $q.defer();

                window.tapjoy.connect(secretKey, function () {
                    deferred.resolve("Tapjoy Success Connect!");
                }, function (error) {
                    deferred.reject("Tapjoy Error Connect!", error);
                });

                return deferred.promise;
            };

            _tapjoy.setDebugEnabled = function (enabled) {
                var deferred = $q.defer();

                window.tapjoy.setDebugEnabled(enabled, function () {
                    deferred.resolve("Tapjoy Success setDebugEnabled!");
                }, function (error) {
                    deferred.reject("Tapjoy Error setDebugEnabled!", error);
                });

                return deferred.promise;
            };

            _tapjoy.setSenderID = function (senderID) {
                var deferred = $q.defer();

                window.tapjoy.setSenderID(senderID, function () {
                    deferred.resolve("Tapjoy Success setSenderID!");
                }, function (error) {
                    deferred.reject("Tapjoy Error setSenderID!", error);
                });

                return deferred.promise;
            };

            _tapjoy.setUserID = function (userId) {
                var deferred = $q.defer();

                window.tapjoy.setUserID(userId, function () {
                    deferred.resolve("Tapjoy Success setUserID!");
                }, function () {
                    deferred.reject("Tapjoy Error setUserID!");
                });

                return deferred.promise;
            };

            _tapjoy.showOffers = function (placementName) {
                var deferred = $q.defer();

                window.tapjoy.showOffers(placementName, function () {
                    deferred.resolve("Tapjoy Success Show Offer!");
                }, function (error) {
                    deferred.reject("Tapjoy Error Show Offer!", error);
                });

                return deferred.promise;
            };

            _tapjoy.onViewClose = function (callback) {
                window.tapjoy.setOnCloseViewNotifier(callback);
            };

            return _tapjoy;
        }

        angular.module("tapJoy", []).factory("$tapjoy", tapJoy);
    })();
});
define("components/trialpay/trialpay", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        trialpay.$inject = ["$q"];
        function trialpay($q) {
            var _trialpay = {};

            _trialpay.initialize = function (appKey, userId) {
                var deferred = $q.defer();

                window.plugins.trialpay.initialize({
                    appKey: appKey,
                    userId: userId
                }, null, function () {
                    deferred.resolve("Trialpay Success Initialize!");
                }, function () {
                    deferred.reject("Trialpay Error Initialize!");
                });

                return deferred.promise;
            };

            _trialpay.showOfferwall = function () {
                var deferred = $q.defer();

                window.plugins.trialpay.showOfferwall(function () {
                    deferred.resolve("Trialpay Success Show OfferWall!");
                }, function () {
                    deferred.reject("Trialpay Error Show OfferWall!");
                });

                return deferred.promise;
            };

            _trialpay.closeOfferwall = function (callback) {
                window.plugins.trialpay.closeOfferwall(callback);
            };

            return _trialpay;
        }

        angular.module("trialpay", []).factory("$trialpay", trialpay);
    })();
});
define("components/vk-api/api", ["exports"], function (exports) {
    "use strict";

    (function (window, angular) {
        "use strict";

        var LOGIN_URL = "https://oauth.vk.com/authorize",

        // LOGOUT_URL = 'https://oauth.vk.com/logout',
        REDIRECT_URL = "https://oauth.vk.com/blank.html",
            API_URL = "https://api.vk.com/method/";

        var storage = window.localStorage,
            runningInCordova = false,
            browserTarget = "_blank",
            browserOptions = "hidden=yes,location=no,toolbar=yes,closebuttoncaption=Готово,disallowoverscroll=yes,mediaPlaybackRequiresUserAction=yes";

        document.addEventListener("deviceready", function () {
            runningInCordova = !window.parent.ripple;
        }, false);

        function parseQueryString(queryString) {
            var qs = decodeURIComponent(queryString),
                obj = {},
                params = qs.split("&");

            params.forEach(function (param) {
                var splitter = param.split("=");
                obj[splitter[0]] = splitter[1];
            });

            return obj;
        }

        function getRedirectUrl() {
            if (runningInCordova) {
                return REDIRECT_URL;
            } else {
                var origin = location.origin,
                    path = location.pathname.substring(0, location.pathname.lastIndexOf("/"));
                return origin + path + "/blank.html";
            }
        }

        function saveAppSettings(settings) {
            storage.setItem("vk_app_id", settings.id);
            storage.setItem("vk_app_permissions", settings.permissions);
        }

        function saveAuthCredentials(credentials) {
            storage.setItem("vk_auth_token", credentials.access_token);
            storage.setItem("vk_auth_user_id", credentials.user_id);
            storage.setItem("vk_auth_expires_in", credentials.expires_in);
        }

        function clearAuthCredentials() {
            delete storage.vk_auth_token;
            delete storage.vk_auth_user_id;
            delete storage.vk_auth_expires_in;
        }

        function injectToolbar(browser) {
            try {
                var toolbarCss = "position:fixed;bottom:0;height:45px;width:100%;background:#5d80a6;",
                    buttonCss = "position:fixed;font-size:15px;padding:12px 16px;color:white;font-weight:700;",
                    buttonHtml = "<a href=\"blank.html?error=cancelled\" style=\"" + buttonCss + "\">Готово</a>";

                browser.executeScript({
                    code: "(function () {\n" + "    var toolbar = document.createElement(\"div\");\n" + "    toolbar.id = \"iab-toolbar\";\n" + "    toolbar.innerHTML = \"" + buttonHtml + "\";\n" + "    document.body.appendChild(toolbar);\n" + "    document.getElementById(\"iab-toolbar\").style.cssText = \"" + toolbarCss + "\";\n" + "})();"
                });
            } catch (e) {}
        }

        function injectInappropriateBlocking(browser) {
            try {
                browser.insertCSS({
                    code: "[class*=\"head\"], [class*=\"foot\"], [class^=\"mmi_\"], [class*=\"create\"] { display: none !important; } \n" + "[class*=\"audio\"], [class*=\"ai_\"], [id*=\"audio\"] { display: none !important; } \n" + ".main_menu, .ipanel, .notify_item, .wi_actions_wrap { display: none !important; } \n" + "#preload_data, #l, #vk_bottom { display: none !important; } \n" + "a[data-href^=\"/write\"], a[href^=\"/write\"] { display: none !important; } \n" + "div.owner_panel { display: block !important; } \n" + "._lm #m { margin: 0 !important; } \n" + ".button.disabled { background: rgba(155, 155, 155, 0.5) !important; } \n" + "a.disabled, a.disabled > i, a.disabled > span { color: #777 !important; }"
                });

                var blockedActions = ["audio", "video", "apps", "//vk.com/"];

                var js = "(function () {\n" + "    var href, target, parent, links, blocked,\n" + "        touchStartPos = {x: 0, y: 0}, touchEndPos = {x: 0, y: 0};\n" + "    function checkIsBlocked(url) {\n" + "        return " + JSON.stringify(blockedActions) + ".some(function (action) {\n" + "            return (url && (url.indexOf(action) !== -1));\n" + "        });\n" + "    }\n" +
                // Method for modifying href and onclick attributes to send them to /dev/null
                "    function filterElement(link) {\n" + "        href = link.getAttribute(\"data-href\") ||\n" + "               link.getAttribute(\"href\");\n" + "        blocked = checkIsBlocked(href);\n" + "        if (blocked) {\n" + "            if (link.hasAttribute(\"data-href\") ||\n" + "                link.hasAttribute(\"href\") ||\n" + "                link.hasAttribute(\"onclick\")\n" + "            ) {\n" + "                link.setAttribute(\"data-href\", \"#\");\n" + "                link.setAttribute(\"href\", \"#\");\n" + "                link.setAttribute(\"onclick\", \"return false;\");\n" + "                link.setAttribute(\"disabled\", \"disabled\");\n" + "                link.classList.add(\"disabled\");\n" + "            }\n" + "        }\n" + "    }\n" +
                // Method for blocking actions produced with inappropriate elements
                "    function filterEvent(event) {\n" + "        target = event.changedTouches[0].target;\n" + "        parent = target.parentNode;\n" + "        href   = target.getAttribute(\"data-href\") ||\n" + "                 target.getAttribute(\"href\");\n" + "        if (!href) {\n" + "            while (parent) {\n" + "                if (parent.hasAttribute && \n" + "                   (parent.hasAttribute(\"data-href\") || parent.hasAttribute(\"href\"))\n" + "                ) {\n" + "                    href = parent.getAttribute(\"data-href\") ||\n" + "                           parent.getAttribute(\"href\");\n" + "                    break;\n" + "                }\n" + "                parent = parent.parentNode;\n" + "            }\n" + "        }\n" + "        blocked = checkIsBlocked(href);\n" + "        if (blocked) {\n" + "            event.preventDefault();\n" + "        }\n" + "    }\n" +
                // href removing
                "    links = document.body.querySelectorAll(\"[data-href], [href]\");\n" + "    Array.prototype.forEach.call(links, function (link) {\n" + "        filterElement(link)\n" + "    });\n" +
                // touches blocking
                "    document.body.addEventListener(\"touchend\", function (event) {\n" + "        filterEvent(event);\n" + "        event.stopPropagation();\n" + "    }, true);\n" +
                // left/right swipes blocking
                "    document.body.addEventListener(\"touchstart\", function (event) {\n" + "        touchStartPos = {\n" + "            x: event.touches[0].pageX,\n" + "            y: event.touches[0].pageY\n" + "        };\n" + "    }, false);\n" + "    document.body.addEventListener(\"touchmove\", function (event) {\n" + "        var touchEndPos = {\n" + "                x: event.touches[0].pageX,\n" + "                y: event.touches[0].pageY\n" + "            },\n" + "            touchDelta = {\n" + "                x: touchEndPos.x - touchStartPos.x,\n" + "                y: touchEndPos.y - touchStartPos.y\n" + "            };\n" + "        if (Math.abs(touchDelta.x) > Math.abs(touchDelta.y)){\n" + "            event.preventDefault();\n" + "            event.stopPropagation();\n" + "        }\n" + "    }, true);\n" + "})();";

                browser.executeScript({
                    code: js
                });
            } catch (e) {}
        }

        /**
         * @ngInject
         */
        function VkApiProvider() {

            VkApi.$inject = ["$rootScope", "$q", "$http"];
            var browser,
                self = this,
                defaults = {
                id: null,
                language: "ru",
                version: "5.21",
                permissions: []
            };

            this.config = function (settings) {
                var config = angular.extend(defaults, settings);
                saveAppSettings(config);

                return config;
            };

            this.$get = VkApi;

            /**
             * @ngInject
             */
            function VkApi($rootScope, $q, $http) {

                function init(settings) {
                    return self.config(settings);
                }

                function initFromUrl(url, key, data) {
                    return $http.get(url, { params: data }).then(function (response) {
                        var settings = response.data || {};
                        if (key) {
                            if (!settings.hasOwnProperty(key)) {
                                return $q.reject({
                                    error: "Vk app configuration could not be found",
                                    error_data: response
                                });
                            }

                            settings = settings[key];
                        }

                        return self.config(settings);
                    });
                }

                function browseTo(url) {
                    var deferred = $q.defer();

                    // check url on http errors. iab loaderror event only fire on url inaccessibility errors.
                    $http.get(url, { nointercept: true }).then(function () {
                        browser = window.open(encodeURI(url), browserTarget, browserOptions);

                        if (runningInCordova && browser) {
                            browser.addEventListener("loadstart", browserLoadStart);
                            browser.addEventListener("loadstop", browserLoadStop);
                            browser.addEventListener("loaderror", browserLoadError);
                            browser.addEventListener("exit", browserExit);
                        } else {
                            window.browserCallback = browserCallback;
                        }
                    })["catch"](function (response) {
                        var data = response.data || {},
                            error = {
                            error_code: data.error_code || response.status,
                            error_msg: data.error_msg || data.error_description || response.statusText
                        };

                        handleError(error).then(function (data) {
                            deferred.resolve(data);
                        }, function (error) {
                            deferred.reject(error);
                        });
                    });

                    function browserLoadStart(event) {
                        var url = event.url;
                        if (url.indexOf("access_token=") > 0 || url.indexOf("error=") > 0 || url.indexOf("fail=") > 0) {
                            browser.close();

                            browserCallback(url).then(function (data) {
                                deferred.resolve(data);
                            }, function (error) {
                                deferred.reject(error);
                            });
                        }
                    }

                    function browserLoadStop(event) {
                        var url = event.url;
                        injectToolbar(browser);
                        if (url.indexOf("oauth.vk.com") === -1 && url.indexOf("m.vk.com/join") === -1 && url.indexOf("m.facebook.com") === -1) {
                            injectInappropriateBlocking(browser);
                        }

                        browser.show();
                    }

                    function browserLoadError(event) {
                        browser.close();
                        deferred.reject({
                            error_code: event.code || 0,
                            error_msg: event.message || "Unknown error"
                        });
                    }

                    function browserExit() {
                        if (!isAuthenticated()) {
                            // If user closed the login window manually before completing the auth process
                            deferred.reject({
                                error_code: -1,
                                error_msg: "User cancelled your request"
                            });
                        } else {
                            deferred.resolve();
                        }
                    }

                    return deferred.promise;
                }

                function browserCallback(url) {
                    var deferred = $q.defer(),
                        queryString,
                        queryObject;

                    if (url.indexOf("access_token=") > 0) {
                        queryString = url.substr(url.indexOf("#") + 1);
                        queryObject = parseQueryString(queryString);

                        saveAuthCredentials(queryObject);

                        deferred.resolve(queryObject);
                    } else if (url.indexOf("error=") > 0) {
                        queryString = url.substring((url.indexOf("#") || url.indexOf("?")) + 1);
                        queryObject = parseQueryString(queryString);

                        handleError(queryObject).then(function (data) {
                            deferred.resolve(data);
                        }, function (error) {
                            deferred.reject(error);
                        });
                    } else {
                        deferred.reject();
                    }

                    return deferred.promise;
                }

                /**
                 * @namespace error.error_code
                 * @namespace error.error_msg
                 * @namespace error.redirect_uri
                 * */
                function handleError(error) {
                    var deferred = $q.defer();

                    error = error || {
                        error_code: 0,
                        error_msg: "UnknownError"
                    };

                    switch (error.error_code) {
                        case 2:
                            // Vk app is turned off
                            $rootScope.$broadcast("VkApiException:WrongApp", error);
                            deferred.reject(error);
                            break;
                        case 5:
                            // Authorization failed
                            clearAuthCredentials();
                            $rootScope.$broadcast("VkApiException:AuthFailed", error);
                            deferred.reject(error);
                            break;
                        case 17:
                            // Validation required - https://vk.com/dev/need_validation
                            if (error.redirect_uri) {
                                clearAuthCredentials();

                                browseTo(error.redirect_uri).then(function (data) {
                                    deferred.resolve(data);
                                }, function (error) {
                                    $rootScope.$broadcast("VkApiException:AuthFailed", error);

                                    deferred.reject(error);
                                });
                            }

                            break;
                        case 101:
                            // Wrong vk app id
                            $rootScope.$broadcast("VkApiException:WrongApp", error);
                            deferred.reject(error);
                            break;
                        case 401:
                            // Unauthorized
                            $rootScope.$broadcast("VkApiException:WrongApp", error);
                            deferred.reject(error);
                            break;
                        default:
                            $rootScope.$broadcast("VkApiException:AuthFailed", error);
                            deferred.reject(error);
                    }

                    return deferred.promise;
                }

                function isAuthenticated() {
                    return !!(storage.vk_auth_token && storage.vk_auth_user_id);
                }

                function getAppId() {
                    return storage.vk_app_id;
                }

                function getVersion() {
                    return defaults.version;
                }

                function getLanguage() {
                    return defaults.language;
                }

                function getPermissions() {
                    return storage.vk_app_permissions;
                }

                function getAccessToken() {
                    return storage.vk_auth_token;
                }

                function getUserId() {
                    return storage.vk_auth_user_id;
                }

                function login() {
                    var authURL = LOGIN_URL + "?client_id=" + getAppId() + "&scope=" + getPermissions() + "&redirect_uri=" + getRedirectUrl() + "&display=mobile&response_type=token";

                    return browseTo(authURL);
                }

                function logout() {
                    clearAuthCredentials();
                }

                function apiCall(httpMethod, apiMethod, apiParams) {
                    httpMethod = httpMethod || "GET";

                    apiParams.v = getVersion();
                    apiParams.lang = getLanguage();
                    apiParams.access_token = getAccessToken();

                    var url = API_URL + apiMethod;

                    return $http({
                        url: url,
                        method: httpMethod,
                        params: apiParams,
                        nointercept: true
                    }).then(function (response) {
                        if (response.data && response.data.error) {
                            throw response;
                        }

                        return response.data;
                    })["catch"](function (response) {
                        var error = response.data.error;

                        return handleError(error).then(function () {
                            return apiCall(httpMethod, apiMethod, apiParams);
                        });
                    });
                }

                function apiGet(apiMethod, apiParams) {
                    return apiCall("GET", apiMethod, apiParams);
                }

                function getGroupById(id) {
                    return apiGet("groups.getById", {
                        group_id: id
                    }).then(function (data) {
                        return data.response[0];
                    });
                }

                function getGroups() {
                    return apiGet("groups.get", {
                        extended: 1
                    }).then(function (data) {
                        return data.response.items;
                    });
                }

                function getCurrentUser() {
                    return apiGet("users.get", {
                        fields: "sex,bdate,photo_50,photo_100,photo_200,screen_name"
                    }).then(function (data) {
                        return data.response[0];
                    });
                }

                function getFriends() {
                    return apiGet("friends.get", {
                        fields: "nickname,photo_50"
                    }).then(function (data) {
                        return data.response.items;
                    });
                }

                function isUser(id) {
                    return apiGet("users.get", {
                        user_ids: id
                    }).then(function (data) {
                        return data.response[0];
                    });
                }

                function getProfiles(ids) {
                    return apiGet("users.get", {
                        user_ids: ids,
                        fields: "photo_100"
                    }).then(function (data) {
                        return data.response;
                    });
                }

                function resolveScreenName(name) {
                    return apiGet("utils.resolveScreenName", {
                        screen_name: name
                    }).then(function (data) {
                        return data.response;
                    });
                }

                function getPostById(id) {
                    return apiGet("wall.getById", {
                        posts: id
                    }).then(function (data) {
                        return data.response[0];
                    });
                }

                return {
                    init: init,
                    initFromUrl: initFromUrl,

                    getAccessToken: getAccessToken,
                    getUserId: getUserId,
                    isAuthenticated: isAuthenticated,
                    isUser: isUser,
                    getProfiles: getProfiles,
                    resolveScreenName: resolveScreenName,
                    browseTo: browseTo,

                    login: login,
                    logout: logout,
                    profile: getCurrentUser,
                    friends: getFriends,
                    group: getGroupById,
                    groups: getGroups,
                    getPostById: getPostById
                };
            }
        }

        angular.module("vkApi", []).provider("VkApi", VkApiProvider);
    })(window, window.angular);
});
define("components/vk-api/services", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        vkVerifyLink.$inject = ["VkApi", "$q"];
        function vkVerifyLink(VkApi, $q) {
            var service = {};

            service.isValidUrl = function (url) {
                var regExp = /^(http|https):\/\/(www\.)?(vk\.com|m\.vk\.com|vkontakte\.ru)\//i;
                return regExp.test(url);
            };

            service.isValidUrlRepost = function (url) {
                var deferred = $q.defer();
                var postInfo = service.resolvePostInfo(url);

                if (postInfo) {
                    VkApi.getPostById(postInfo[1]).then(function (reponse) {
                        deferred.resolve(reponse);
                    }, function (error) {
                        deferred.reject(error);
                    });
                } else {
                    deferred.reject("Url " + url + "is not valid");
                }

                return deferred.promise;
            };

            service.resolvePostInfo = function (url) {
                var matches = url.toLowerCase().match(/.*\b(photo|video|audio|wall)([0-9-_]+)/);

                if (matches instanceof Array) {
                    matches = matches.splice(1, 2);

                    return matches.length < 2 ? null : matches;
                }

                return null;
            };

            service.getPathName = function (url) {
                var parser = document.createElement("a");
                parser.href = url;
                return parser.pathname.replace("/", "");
            };

            service.validUrlGroup = function (url) {
                var deferred = $q.defer();

                if (typeof url !== "undefined" && this.isValidUrl(url)) {
                    var name = this.getPathName(url);

                    if (name) {
                        VkApi.resolveScreenName(name).then(function (data) {

                            if (data.type && data.type === "group" && data.object_id) {
                                VkApi.group(data.object_id).then(function (data) {
                                    deferred.resolve(data);
                                }, function () {
                                    deferred.reject("Group" + data.object_id + " not find");
                                });
                            } else {
                                deferred.reject("Url " + url + "is not group");
                            }
                        }, function (error) {
                            deferred.reject(error);
                        });
                    } else {
                        deferred.reject("Url " + url + "is not valid");
                    }
                } else {
                    deferred.reject("Url " + url + "is not valid");
                }

                return deferred.promise;
            };

            return service;
        }

        angular.module("vkServices", []).factory("$vkVerifyLink", vkVerifyLink);
    })();
});
define("modules/advert/advert", ["exports"], function (exports) {
    "use strict";

    angular.module("tap2app-app.advert", ["tap2app-app.advert.services", "tap2app-app.advert.directives"]);
});
define("modules/advert/directives", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        function adverts() {
            return {
                restrict: "E",
                templateUrl: "templates/modules/advert/views/list.tpl.html",
                replace: true,
                scope: true,
                controller: ["$scope", "$attrs", "AdvertsService", function controller($scope, $attrs, AdvertsService) {
                    this.initAdverts = function () {
                        $scope.adverts = [];

                        return AdvertsService.list().then(function (adverts) {
                            if (adverts.data) {
                                $scope.adverts = adverts.data.data;
                            }
                        });
                    };
                }],
                link: function link($scope, $element, $attrs, ctrl) {
                    ctrl.initAdverts();
                }
            };
        }

        angular.module("tap2app-app.advert.directives", []).directive("adverts", adverts);
    })();
});
define("modules/advert/services", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        AdvertsService.$inject = ["$http", "Config"];
        function AdvertsService($http, Config) {
            return {
                list: function list(data) {
                    return $http.get(Config.API_BASEURL + "/adverts", { params: data });
                }
            };
        }

        angular.module("tap2app-app.advert.services", []).factory("AdvertsService", AdvertsService);
    })();
});
define("components/votes/votes", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        VotesService.$inject = ["$http", "Config"];
        function VotesService($http, Config) {
            return {
                rate: function rate() {
                    return $http.get(Config.API_BASEURL + "/votes/rate");
                }
            };
        }

        angular.module("votes", []).factory("VotesService", VotesService);
    })();
});
define("modules/auth/auth", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        configStateProvider.$inject = ["$stateProvider"];
        AuthController.$inject = ["$scope", "$state", "$ionicLoading", "Config", "VkApi"];
        function configStateProvider($stateProvider) {
            $stateProvider.state("auth", {
                url: "/auth",
                templateUrl: "templates/modules/auth/layout.tpl.html",
                abstract: true
            }).state("auth.login", {
                url: "/login",
                templateUrl: "templates/modules/auth/login.tpl.html",
                controller: "AuthController"
            }).state("auth.logout", {
                url: "/logout",
                templateUrl: "templates/modules/auth/login.tpl.html",
                controller: "AuthController"
            });
        }

        /**
         * @ngInject
         */
        function AuthController($scope, $state, $ionicLoading, Config, VkApi) {

            VkApi.logout();

            $scope.login = function () {
                $ionicLoading.show({ template: "Загрузка vk.com ..." });

                VkApi.initFromUrl(Config.API_BASEURL + "/app/renew", "vk_app", {
                    nointercept: true
                }).then(function () {
                    return VkApi.login();
                }).then(function () {
                    $scope.$emit("auth.logged.in");

                    $state.go("tasks-feed");
                })["catch"](function (error) {})["finally"](function () {
                    $ionicLoading.hide();
                });
            };
        }

        angular.module("tap2app-app.auth", ["ui.router"]).config(configStateProvider).controller("AuthController", AuthController);
    })();
});
define("modules/home/home", ["exports"], function (exports) {
    "use strict";

    angular.module("tap2app-app.home", ["ui.router"]).config(["$stateProvider", function ($stateProvider) {
        $stateProvider.state("home", {
            parent: "root",
            url: "/home",
            templateUrl: "templates/modules/home/index.tpl.html",
            controller: "HomeController",
            data: {
                showTabs: false
            }
        });
    }]).controller("HomeController", ["$scope", function ($scope) {}]);
});
define("modules/task/controllers", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        TasksController.$inject = ["$scope", "$rootScope", "$state", "$stateParams", "$tapjoy", "$supersonic", "$fyber", "$trialpay", "$cordovaDialogs", "$q", "$ionicLoading", "TasksService", "Config", "VkApi"];
        TaskController.$inject = ["$rootScope", "$scope", "$state", "$stateParams", "$ionicModal", "TasksService"];
        function TasksController($scope, $rootScope, $state, $stateParams, $tapjoy, $supersonic, $fyber, $trialpay, $cordovaDialogs, $q, $ionicLoading, TasksService, Config, VkApi) {
            $scope.tasks = [];
            $scope.lastViewedTask = TasksService.toObject($stateParams.task);
            $scope.noMoreItemsAvailable = false;
            $scope.emptyContent = false;
            $scope.nextPage = 1;

            TasksService.sdks().then(function (response) {
                $scope.sdks = response.data;
            });

            function completeTask(task) {
                $scope.tasks.some(function (entry, index) {
                    if (entry.id === task.id) {
                        $scope.tasks.splice(index, 1);
                    }
                });

                $rootScope.$broadcast("userBalance.Refresh");
            }

            // remove completed task from scope when returning from task-view
            if ($scope.lastViewedTask) {
                completeTask($scope.lastViewedTask);
            }

            function fetchData(isPullToRefresh, finallyCallback) {
                TasksService.list({ page: $scope.nextPage, type: $stateParams.type }).success(function (response) {

                    if (isPullToRefresh) {
                        $scope.emptyContent = false;
                        $scope.tasks = [];
                    }

                    $scope.tasks = $scope.tasks.concat(response.data);
                    $scope.nextPage = response.meta.pagination.current_page + 1;
                    $scope.$broadcast("scroll.infiniteScrollComplete");

                    if ($scope.tasks.length == response.meta.pagination.total) {
                        $scope.noMoreItemsAvailable = true;
                    }

                    /**
                     * @TODO отображение инфо, если нету заданий
                     * задания пока всегда есть, т.к. подключены задания от партеров (Tapjoy)
                     */
                    /*if ($scope.tasks.length == 0) {
                        $scope.emptyContent = true;
                    }*/
                })["finally"](finallyCallback);
            }

            function refreshComplete() {
                $scope.$broadcast("scroll.refreshComplete");
            }

            $scope.loadMore = function () {
                fetchData(false);
            };

            $scope.doRefresh = function () {
                $scope.nextPage = 1;
                $scope.noMoreItemsAvailable = false;

                fetchData(true, refreshComplete);
            };

            $scope.perform = function (task) {
                var startedTaskInfo = { id: task.id, type: task.type, title: task.title, link: task.link };

                verifyTypeTask(task).then(function () {
                    processingTask(task);
                }, function (reason) {
                    $cordovaDialogs.alert(reason, "Ошибка", "OK");
                    disableTask(task);
                });

                function processingTask(task) {
                    if (task.type !== "join_group") {
                        $state.go("task-view", {
                            task: TasksService.toString(task)
                        }, {
                            location: false,
                            inherit: false
                        });
                    } else {
                        $ionicLoading.show({ template: "Загрузка vk.com ..." });

                        TasksService.perform(task).then(function (task) {
                            TasksService.verify(task.id).then(successTaskVerification);
                        })["catch"](function (error) {})["finally"](function () {
                            $ionicLoading.hide();
                        });
                    }
                }

                function successTaskVerification(task) {
                    $scope.tasks.some(function (entry, index) {
                        if (entry.id === task.id) {
                            $scope.tasks.splice(index, 1);
                        }
                    });

                    $rootScope.$broadcast("userBalance.Refresh");
                }
            };

            function verifyTypeTask(task) {
                var deferred = $q.defer();

                if (task.type === "join_group") {
                    VkApi.group(task.target).then(function (group) {
                        if (group.is_closed) {
                            deferred.reject("Эта группа является закрытой! Невозможно выполнить задание!");
                        } else {
                            deferred.resolve();
                        }
                    });
                } else {
                    deferred.resolve();
                }

                return deferred.promise;
            }

            function disableTask(task) {
                task.active = false;
                TasksService.disable(task.id);
            }

            function onViewTapjoyClose() {
                $rootScope.$broadcast("userBalance.Refresh");

                /**
                 * @TODO вешается новое событие на закрытие окна таджоя, пример:
                 * Я выполняю задание, т.е. просматриваю видео.
                 * Когда видео я посмотрел, то в тапжое срабатывает событие,
                 * что окно тапжоя закрылось (а на самом деле не закрылось).
                 * Для этого приходится еще раз заново вешать событие когда уже закроется окно тапжоя
                 * и обновить баланс юсера, чтобы юсер видел, что начислились монеты
                 */
                $tapjoy.onViewClose(function () {
                    $rootScope.$broadcast("userBalance.Refresh");
                });
            }

            var callbacks = {
                openTapjoy: function openTapjoy() {
                    $ionicLoading.show({
                        template: "Загрузка..."
                    });

                    $tapjoy.showOffers().then(function () {})["catch"](function (error) {})["finally"](function () {
                        $ionicLoading.hide();
                    });

                    $tapjoy.onViewClose(onViewTapjoyClose);
                },
                openSupersonic: function openSupersonic() {
                    $supersonic.showOfferwall();
                    $supersonic.closeOfferwall(function () {
                        $rootScope.$broadcast("userBalance.Refresh");
                    });
                },
                openFyber: function openFyber() {
                    $fyber.showOfferwall().then(function () {})["catch"](function (error) {});

                    $fyber.onCloseOfferWall(function () {
                        $rootScope.$broadcast("userBalance.Refresh");
                    });
                },
                openTrialpay: function openTrialpay() {
                    $trialpay.showOfferwall().then(function () {})["catch"](function (error) {});

                    $trialpay.closeOfferwall(function () {
                        $rootScope.$broadcast("userBalance.Refresh");
                    });
                }
            };

            $scope.open = function (callback) {
                if (typeof callbacks[callback] === "function") {
                    callbacks[callback]();
                }
            };
        }

        /**
         * @ngInject
         */
        function TaskController($rootScope, $scope, $state, $stateParams, $ionicModal, TasksService) {
            $rootScope.$state = $state;
            $scope.task = TasksService.toObject($stateParams.task);

            var instructionsTemplate = "templates/modules/task/views/modal.instructions.tpl.html";

            $scope.cancel = function (task) {
                $state.go("tasks-feed", undefined, { location: false, inherit: false });
            };

            $scope.perform = function (task) {
                return TasksService.perform(task);
            };

            $scope.verify = function (task) {
                if (window.plugins.appsManager) {
                    window.plugins.appsManager.getRunningApps(function (apps) {
                        TasksService.verify(task.id, { apps: apps }).then(function (task) {
                            $state.go("tasks-feed", {
                                task: TasksService.toString(task)
                            }, {
                                location: false,
                                inherit: false
                            });
                        }, function (response) {
                            if (response.data && response.data.error && response.data.error.message) {
                                alert(response.data.error.message);
                            } else {
                                alert("Приложение не установлено или не запущено! Монеты не начислены.");
                            }
                        });
                    }, function (error) {});
                } else {}
            };

            $ionicModal.fromTemplateUrl(instructionsTemplate, function (modal) {
                $scope.modalInstructions = modal;
            }, {
                scope: $scope,
                animation: "slide-in-up"
            });
        }

        angular.module("tap2app-app.task.controllers", []).controller("TasksController", TasksController).controller("TaskController", TaskController);
    })();
});
define("modules/task/routes", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        configStateProvider.$inject = ["$stateProvider"];
        function configStateProvider($stateProvider) {
            $stateProvider.state("tasks-feed", {
                parent: "root",
                url: "/feed/tasks?task",
                templateUrl: "templates/modules/task/views/feed.tpl.html",
                controller: "TasksController",
                data: {
                    showTabs: true
                }
            }).state("task-view", {
                parent: "root",
                url: "/task/view?task",
                templateUrl: "templates/modules/task/views/view.tpl.html",
                controller: "TaskController",
                data: {
                    showTabs: true
                }
            });
        }

        angular.module("tap2app-app.task.routes", []).config(configStateProvider);
    })();
});
define("modules/task/services", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        TasksService.$inject = ["$http", "$q", "VkApi", "Config"];
        function TasksService($http, $q, VkApi, Config) {
            return {
                list: function list(data) {
                    return $http.get(Config.API_BASEURL + "/tasks", { params: data });
                },

                view: function view(id, data) {
                    return $http.get(Config.API_BASEURL + "/tasks/" + id, { params: data });
                },

                disable: function disable(id) {
                    return $http["delete"](Config.API_BASEURL + "/tasks/" + id);
                },

                perform: function perform(task) {
                    var url = encodeURI(task.link);

                    if (!/^http(s)?:\/\//i.test(url)) {
                        url = "https://" + url;
                    }

                    if (task.type !== "join_group") {
                        window.open(url, "_system");
                    } else {
                        return VkApi.browseTo(url).then(function () {
                            return task;
                        });
                    }

                    return $q.when(task);
                },

                verify: function verify(id, data) {
                    return $http.post(Config.API_BASEURL + "/tasks/" + id + "/verify", data, {
                        nointercept: true
                    }).then(function (response) {
                        return response.data.data;
                    });
                },

                rates: function rates() {
                    return $http.get(Config.API_BASEURL + "/tasks/rates").then(function (response) {
                        return response.data;
                    });
                },

                sdks: function sdks() {
                    return $http.get(Config.API_BASEURL + "/sdks").then(function (response) {
                        return response.data;
                    });
                },

                toString: function toString(task) {
                    if (task) {
                        return JSON.stringify(task);
                    }

                    return undefined;
                },

                toObject: function toObject(task) {
                    if (task) {
                        try {
                            var obj = JSON.parse(task);

                            if (obj && typeof obj === "object" && obj !== null) {
                                return obj;
                            }
                        } catch (e) {}
                    }

                    return undefined;
                }
            };
        }

        angular.module("tap2app-app.task.services", []).factory("TasksService", TasksService);
    })();
});
define("modules/task/task", ["exports"], function (exports) {
    "use strict";

    angular.module("tap2app-app.task", ["tap2app-app.task.controllers", "tap2app-app.task.routes", "tap2app-app.task.services", "ui.router"]);
});
define("modules/user/config", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        var REQUEST_STATUSES = {
            wait: "Ожидает",
            done: "Завершено",
            cancelled: "Отменено"
        };

        angular.module("tap2app-app.user.config", []).constant("REQUEST_STATUSES", REQUEST_STATUSES);
    })();
});
define("modules/user/controllers", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        UserRequestsController.$inject = ["$scope", "UserRequestService", "REQUEST_STATUSES"];
        UserReferralController.$inject = ["$state", "$scope", "$rootScope", "VkApi", "UserReferralService", "rate"];
        UserReferralsController.$inject = ["$scope", "$ionicActionSheet", "$cordovaClipboard", "$cordovaEmailComposer", "UserReferralService", "profile", "ratio"];
        UserRateAppController.$inject = ["$scope", "$state"];
        UserFeedbackController.$inject = ["$scope", "$state", "$cordovaDialogs", "UserFeedbackService"];
        function UserRequestsController($scope, UserRequestService, REQUEST_STATUSES) {
            $scope.statuses = REQUEST_STATUSES;
            $scope.noMoreItemsAvailable = false;
            $scope.emptyContent = false;
            $scope.requests = [];
            $scope.nextPage = 1;

            $scope.loadMore = function () {
                UserRequestService.list({ page: $scope.nextPage }).success(function (response) {
                    $scope.requests = $scope.requests.concat(response.data);
                    $scope.nextPage = response.meta.pagination.current_page + 1;
                    $scope.$broadcast("scroll.infiniteScrollComplete");

                    if ($scope.requests.length == response.meta.pagination.total) {
                        $scope.noMoreItemsAvailable = true;
                    }

                    if ($scope.requests.length == 0) {
                        $scope.emptyContent = true;
                    }
                });
            };

            $scope.generateLink = function (data) {
                return angular.isNumber(data) ? "http://vk.com/id" + data : "http://vk.com/" + data;
            };
        }

        /**
        * @ngInject
        */
        function UserReferralController($state, $scope, $rootScope, VkApi, UserReferralService, rate) {

            var userId = VkApi.getUserId();

            $scope.rate = rate;
            $scope.errors = false;
            $scope.data = {
                senderId: userId
            };

            $scope.submit = function (data) {
                UserReferralService.submitCode(data).success(function (response) {
                    $rootScope.profile.ref_id = response.ref_id;
                    $rootScope.$broadcast("userBalance.Refresh");
                    $state.go("tasks-feed");
                });
            };
        }

        /**
        * @ngInject
        */
        function UserReferralsController($scope, $ionicActionSheet, $cordovaClipboard, $cordovaEmailComposer, UserReferralService, profile, ratio) {

            $scope.noMoreItemsAvailable = false;
            $scope.emptyContent = false;
            $scope.referrals = [];
            $scope.nextPage = 1;
            $scope.code = profile.new_referral_code;
            $scope.ratio = ratio;

            $scope.loadMore = function () {
                UserReferralService.list({ page: $scope.nextPage }).then(function (response) {
                    $scope.referrals = $scope.referrals.concat(response.data);
                    $scope.nextPage = response.meta.pagination.current_page + 1;
                    $scope.$broadcast("scroll.infiniteScrollComplete");

                    if ($scope.referrals.length == response.meta.pagination.total) {
                        $scope.noMoreItemsAvailable = true;
                    }

                    if ($scope.referrals.length == 0) {
                        $scope.emptyContent = true;
                    }
                });
            };

            $scope.actions = function (code, coins) {
                $ionicActionSheet.show({
                    buttons: [{ text: "Скопировать" }, { text: "Отправить почтой" }],
                    buttonClicked: function (index) {

                        if (index === 0) {
                            $cordovaClipboard.copy(code);
                        } else if (index === 1) {
                            var body = "Получи " + coins + " монет в приложении \"Голоса для ВК\". Вводи код " + code;

                            $cordovaEmailComposer.open({
                                app: "mailto:",
                                body: body
                            });
                        }

                        return true;
                    }
                });
            };
        }

        /**
        * @ngInject
        */
        function UserRateAppController($scope, $state) {
            $scope.rate = function (rating) {
                if (rating > 2) {
                    $state.go("tasks-feed");

                    window.open(encodeURI("http://play.google.com/store/apps/details?id=ru.startupteam.tap2app"), "_system");
                } else {
                    $state.go("user-feedback");
                }
            };
        }

        /**
        * @ngInject
        */
        function UserFeedbackController($scope, $state, $cordovaDialogs, UserFeedbackService) {
            $scope.feedback = function (data) {
                UserFeedbackService.create(data).success(function () {
                    $cordovaDialogs.alert("Спасибо, что отправил(а) отзыв! Мы скоро свяжемся с тобой.", " ");
                    $state.go("tasks-feed");
                });
            };
        }

        angular.module("tap2app-app.user.controllers", []).controller("UserRequestsController", UserRequestsController).controller("UserReferralController", UserReferralController).controller("UserReferralsController", UserReferralsController).controller("UserRateAppController", UserRateAppController).controller("UserFeedbackController", UserFeedbackController);
    })();
});
define("modules/user/directives", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        verifyLink.$inject = ["$vkVerifyLink"];
        function verifyLink($vkVerifyLink) {
            function isValid(value) {
                return $vkVerifyLink.isValidUrl(value) && $vkVerifyLink.getPathName(value);
            }

            return {
                require: "ngModel",
                link: function link(scope, elm, attrs, ngModelCtrl) {

                    ngModelCtrl.$parsers.unshift(function (viewValue) {
                        ngModelCtrl.$setValidity("verifyLink", isValid(viewValue));
                        return viewValue;
                    });

                    ngModelCtrl.$formatters.unshift(function (modelValue) {
                        ngModelCtrl.$setValidity("verifyLink", isValid(modelValue));
                        return modelValue;
                    });
                }
            };
        }

        function userBalance() {
            return {
                restrict: "AE",
                template: "<span>{{ balance }}</span>",
                require: "userBalance",
                replace: true,
                scope: true,
                controller: ["$scope", "$attrs", "$filter", "UserService", function controller($scope, $attrs, $filter, UserService) {
                    this.initBalance = function () {
                        $scope.balance = "Обновление баланса";

                        return UserService.getBalance().then(function (balance) {
                            if (typeof balance === "number") {
                                $scope.balance = $filter("number")(balance, 0) + " монет";
                            } else {
                                $scope.balance = "Ошибка обновления!";
                            }
                        })["catch"](function () {
                            $scope.balance = "Ошибка подключения!";
                        })["finally"](function () {});
                    };
                }],
                link: function link($scope, $element, $attrs, ctrl) {
                    ctrl.initBalance();

                    $scope.$on("userBalance.Refresh", function () {
                        ctrl.initBalance();
                    });

                    $scope.$on("$destroy", function () {});
                }
            };
        }

        function starRating() {
            return {
                restrict: "A",
                template: "<ul class=\"rating\">" + "<li ng-repeat=\"star in stars\" ng-class=\"star\" ng-click=\"toggle($index)\">" + "<i class=\"ion-android-star\"></i>" + "</li>" + "</ul>",
                scope: {
                    ratingValue: "=",
                    max: "="
                },
                link: function link(scope) {
                    var updateStars = function updateStars() {
                        scope.stars = [];
                        for (var i = 0; i < scope.max; i++) {
                            scope.stars.push({
                                filled: i < scope.ratingValue
                            });
                        }
                    };

                    scope.toggle = function (index) {
                        scope.ratingValue = index + 1;
                    };

                    scope.$watch("ratingValue", function () {
                        updateStars();
                    });
                }
            };
        }

        function userRequestWaitCoins() {
            return {
                restrict: "A",
                template: "<span>{{ coins }}</span>",
                replace: true,
                scope: true,
                controller: ["$scope", "$attrs", "$filter", "UserService", function controller($scope, $attrs, $filter, UserService) {
                    this.initCoins = function () {
                        $scope.coins = "";

                        return UserService.getTotalCoinsWaitingRequests().then(function (coins) {
                            if (typeof coins === "number") {
                                $scope.coins = "(+" + $filter("number")(coins, 0) + " на заявках)";
                            }
                        });
                    };
                }],
                link: function link($scope, $element, $attrs, ctrl) {
                    ctrl.initCoins();

                    $scope.$on("userBalance.Refresh", function () {
                        ctrl.initCoins();
                    });
                }
            };
        }

        angular.module("tap2app-app.user.directives", []).directive("verifyLink", verifyLink).directive("userBalance", userBalance).directive("userRequestWaitCoins", userRequestWaitCoins).directive("starRating", starRating);
    })();
});

//

//
define("modules/user/routes", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        configStateProvider.$inject = ["$stateProvider"];
        function configStateProvider($stateProvider) {
            $stateProvider.state("user-profile", {
                parent: "root",
                url: "/user/profile",
                templateUrl: "templates/modules/user/views/profile.index.tpl.html",
                data: {
                    showTabs: true
                }
            }).state("user-requests", {
                parent: "root",
                url: "/user/requests",
                templateUrl: "templates/modules/user/views/request.index.tpl.html",
                controller: "UserRequestsController",
                data: {
                    showTabs: true
                }
            }).state("user-referrals", {
                parent: "root",
                url: "/user/referral",
                templateUrl: "templates/modules/user/views/referral.index.tpl.html",
                controller: "UserReferralsController",
                resolve: {
                    ratio: ["UserReferralService", function ratio(UserReferralService) {
                        return UserReferralService.ratio().then(function (resolve) {
                            return resolve.data;
                        });
                    }]
                },
                data: {
                    showTabs: true
                }
            }).state("user-referral-code", {
                parent: "root",
                url: "/user/referral/code",
                templateUrl: "templates/modules/user/views/referral.form.tpl.html",
                controller: "UserReferralController",
                resolve: {
                    rate: ["UserReferralService", function rate(UserReferralService) {
                        return UserReferralService.rate().then(function (resolve) {
                            return resolve.data;
                        });
                    }]
                },
                data: {
                    showTabs: true
                }
            }).state("user-rate-app", {
                parent: "root",
                url: "/user/rate/app",
                templateUrl: "templates/modules/user/views/rate.app.tpl.html",
                controller: "UserRateAppController",
                data: {
                    showTabs: true
                }
            }).state("user-feedback", {
                parent: "root",
                url: "/user/feedback",
                templateUrl: "templates/modules/user/views/feedback.form.tpl.html",
                controller: "UserFeedbackController",
                data: {
                    showTabs: true
                }
            });
        }

        angular.module("tap2app-app.user.routes", []).config(configStateProvider);
    })();
});
define("modules/user/services", ["exports"], function (exports) {
    "use strict";

    (function () {
        "use strict";

        /**
         * @ngInject
         */
        UserService.$inject = ["$http", "$q", "VkApi", "Config"];
        UserFeedbackService.$inject = ["$http", "Config"];
        UserRequestService.$inject = ["$http", "Config"];
        UserReferralService.$inject = ["$http", "Config", "VkApi"];
        function UserService($http, $q, VkApi, Config) {
            function getProfile() {
                return VkApi.profile().then(function (profile) {
                    return $http.get(Config.API_BASEURL + "/profile").then(function (response) {
                        angular.extend(profile, response.data.data);
                        return profile;
                    });
                });
            }

            function getBalance() {
                return $http.get(Config.API_BASEURL + "/profile/balance", {
                    ignoreLoadingBar: true
                }).then(function (response) {
                    return response.data;
                });
            }

            function getBonus() {
                return $http.get(Config.API_BASEURL + "/profile/bonus", {
                    nointercept: true
                }).then(function (response) {
                    if (!response.data) {
                        return $q.reject();
                    }
                    return response.data;
                });
            }

            function getTotalCoinsWaitingRequests() {
                return $http.get(Config.API_BASEURL + "/profile/requests/wait/total", {
                    ignoreLoadingBar: true
                }).then(function (response) {
                    return response.data;
                });
            }

            return {
                getProfile: getProfile,
                getBalance: getBalance,
                getBonus: getBonus,
                getTotalCoinsWaitingRequests: getTotalCoinsWaitingRequests
            };
        }

        /**
         * @ngInject
         */
        function UserFeedbackService($http, Config) {
            return {
                create: function create(request) {
                    return $http.post(Config.API_BASEURL + "/feedbacks", request);
                }
            };
        }

        /**
         * @ngInject
         */
        function UserRequestService($http, Config) {

            return {
                list: function list(data) {
                    return $http.get(Config.API_BASEURL + "/profile/requests", {
                        params: data
                    });
                },
                create: function create(request) {
                    return $http.post(Config.API_BASEURL + "/profile/requests", request);
                }
            };
        }

        /**
         * @ngInject
         */
        function UserReferralService($http, Config, VkApi) {

            return {
                list: function list(data) {
                    return $http.get(Config.API_BASEURL + "/profile/referral", {
                        params: data
                    }).then(function (response) {
                        var ids,
                            userTasks = {},
                            referrals = response.data;

                        angular.forEach(referrals.data, function (referral) {
                            userTasks[referral.profile_id] = referral.completed_tasks;
                        });

                        ids = Object.keys(userTasks);

                        return VkApi.getProfiles(ids.join()).then(function (profiles) {
                            angular.forEach(profiles, function (profile) {
                                profile.full_name = profile.first_name + " " + profile.last_name;
                                profile.completed_tasks = userTasks[profile.id];
                            });

                            referrals.data = profiles;

                            return referrals;
                        });
                    });
                },
                submitCode: function submitCode(request) {
                    return $http.post(Config.API_BASEURL + "/profile/referral", request);
                },
                rate: function rate() {
                    return $http.get(Config.API_BASEURL + "/referral/rate");
                },
                ratio: function ratio() {
                    return $http.get(Config.API_BASEURL + "/referral/ratio");
                }
            };
        }

        angular.module("tap2app-app.user.services", []).factory("UserService", UserService).factory("UserRequestService", UserRequestService).factory("UserReferralService", UserReferralService).factory("UserFeedbackService", UserFeedbackService);
    })();
});
define("modules/user/user", ["exports"], function (exports) {
    "use strict";

    angular.module("tap2app-app.user", ["tap2app-app.user.config", "tap2app-app.user.controllers", "tap2app-app.user.routes", "tap2app-app.user.services", "tap2app-app.user.directives", "ngSpinbox", "ui.router", "votes"]);
});
//# sourceMappingURL=app.bundle.js.map
