cordova.define("cordova-plugin-tapjoy.TapjoyPlugin", function(require, exports, module) {
var exec = require('cordova/exec');

var Tapjoy = function () {
    this.serviceName = 'TapjoyPlugin';
};

/**
 * Initialize Tapjoy Connect
 *
 * @param secretKey         The Tapjoy Secret Key.
 * @param successCallback   The success callback
 * @param failureCallback   The error callback
 */
Tapjoy.prototype.connect = function (secretKey, successCallback, failureCallback) {
    return exec(
        successCallback,
        failureCallback,
        this.serviceName,
        'connect',
        [secretKey]);
};

/**
 * Sets a userID for this device/account.
 * Debug mode enables you to see logs of various
 * Tapjoy actions (sessions, placements, purchases, custom events, etc. ).
 * These will appear in the Tapjoy Developer Console.
 * Do not enable this for any version of the game released to an app store!
 *
 * @param enabled           True or false.
 * @param successCallback   The success callback
 * @param failureCallback   The error callback
 *
 * @see http://dev.tapjoy.com/sdk-integration/android/getting-started-guide-publishers-android/#debug_mode_developer_console
 * @see http://dev.tapjoy.com/sdk-integration/ios/getting-started-guide-publishers-ios/#debug_mode_developer_console
 */
Tapjoy.prototype.setDebugEnabled = function (enabled, successCallback, failureCallback) {
    return exec(
        successCallback,
        failureCallback,
        this.serviceName,
        'setDebugEnabled',
        [enabled]);
};

/**
 * @param disabled          True or false
 * @param successCallback   The success callback
 * @param failureCallback   The error callback
 * @returns {*}
 */
Tapjoy.prototype.setPushNotificationDisabled = function (disabled, successCallback, failureCallback) {
    return exec(
        successCallback,
        failureCallback,
        this.serviceName,
        'setPushNotificationDisabled',
        [disabled]);
};

/**
 * Sets a userID for this device/account.
 * This can only be used with non-managed currency and must be called before
 * showing the Marketplace, Display ads, Featured ad, etc.
 *
 * @param userID            The ID you wish to use for this user/account.
 * @param successCallback   The success callback
 * @param failureCallback   The error callback
 */
Tapjoy.prototype.setUserID = function (userID, successCallback, failureCallback) {
    return exec(
        successCallback,
        failureCallback,
        this.serviceName,
        'setUserID',
        [userID]);
};

/**
 * Sets your GCM Sender ID.
 *
 * @param senderID          The GCM Sender ID.
 * @param successCallback   The success callback
 * @param failureCallback   The error callback
 *
 * @see http://dev.tapjoy.com/sdk-integration/android/getting-started-guide-publishers-android/#push_notifications
 */
Tapjoy.prototype.setSenderID = function (senderID, successCallback, failureCallback) {
    return exec(
        successCallback,
        failureCallback,
        this.serviceName,
        'setSenderID',
        [senderID]);
};

/**
 * Show Marketplace
 *
 * @param placementName     The Placement name string. Default set to 'offerwall_unit'.
 * @param successCallback   The success callback
 * @param failureCallback   The error callback
 *
 * @see http://dev.tapjoy.com/sdk-integration/android/getting-started-guide-publishers-android/#placements
 * @see http://dev.tapjoy.com/sdk-integration/ios/getting-started-guide-publishers-ios/#placements
 */
Tapjoy.prototype.showOffers = function (placementName, successCallback, failureCallback) {
    placementName = placementName || 'offerwall_unit';

    return exec(
        successCallback,
        failureCallback,
        this.serviceName,
        'showOffers',
        [placementName]);
};

/**
 * Sets on close view notifier
 *
 * @param successCallback   The success callback
 * @param failureCallback   The error callback
 */
Tapjoy.prototype.setOnCloseViewNotifier = function (successCallback, failureCallback) {
    return exec(
        successCallback,
        failureCallback,
        this.serviceName,
        'setOnCloseViewNotifier',
        []);
};

module.exports = new Tapjoy();

});
